# coding: utf-8

"""
    RobotnikAI API

    Documentation of API endpoints of RobotnikAI for SDK

    The version of the OpenAPI document: 0.2.2
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class HmacKeyFormatEnum(str, Enum):
    """
    * `base64` - Base64 * `hex` - Hexadecimal * `raw` - Raw (no encoding)
    """

    """
    allowed enum values
    """
    BASE64 = 'base64'
    HEX = 'hex'
    RAW = 'raw'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of HmacKeyFormatEnum from a JSON string"""
        return cls(json.loads(json_str))


